#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="owncast/owncast:latest"
}

do_install_detail() {
  local config=`uci get owncast.@owncast[0].config_path 2>/dev/null`
  local port=`uci get owncast.@owncast[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get owncast.@owncast[0].image_name 2>/dev/null`
  local username=`uci get owncast.@owncast[0].username 2>/dev/null`
  local password=`uci get owncast.@owncast[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8387
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=owncast/owncast:latest

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: '3.8'
services:
  owncast:
    image: owncast/owncast:latest
    restart: unless-stopped
    ports:
      - "$port:8080"
    environment:
      - OWNCAST_ADMIN_USERNAME=admin
      - OWNCAST_ADMIN_PASSWORD=password
      - OWNCAST_TITLE=My Owncast Stream
      - OWNCAST_STREAM_KEY=${GEN_PASS}
      - OWNCAST_HTTP_ROOT=/stream
    volumes:
      - $config:/app/data
    labels:
      plugsy.name: "Owncast"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/simple-icons/Owncast"
      plugsy.link: "http://${LAN_IP}:$port"
# Fw internal/external TorGuard wireguard port tcp 1935
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

  echo "Default username is admin and default password is password."
  echo "Your Owncast Stream Key is:" {$GEN_PASS}
  echo "Please make note of these details"
}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install owncast"
  echo "      upgrade                Upgrade owncast"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart owncast"
  echo "      status                 owncast status"
  echo "      port                   owncast port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f owncast
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} owncast
  ;;
  "status")
    docker ps --all -f 'name=owncast' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=owncast' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
